Package: future.callr
Version: 0.8.2
Depends: R (>= 3.4.0), future (>= 1.33.0)
Imports: callr (>= 2.0.3)
Suggests: globals, future.apply, listenv, markdown, R.rsp
VignetteBuilder: R.rsp
Title: A Future API for Parallel Processing using 'callr'
Authors@R: c(person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                          email = "henrikb@braju.com"))
Description: Implementation of the Future API on top of the 'callr' package.  This allows you to process futures, as defined by the 'future' package, in parallel out of the box, on your local (Linux, macOS, Windows, ...) machine.  Contrary to backends relying on the 'parallel' package (e.g. 'future::multisession') and socket connections, the 'callr' backend provided here can run more than 125 parallel R processes.
License: LGPL (>= 2.1)
LazyLoad: TRUE
URL: https://future.callr.futureverse.org,
        https://github.com/HenrikBengtsson/future.callr
BugReports: https://github.com/HenrikBengtsson/future.callr/issues
RoxygenNote: 7.2.3
Roxygen: list(markdown = TRUE)
Author: Henrik Bengtsson [aut, cre, cph]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Built: R 4.4.0; ; 2024-05-03 01:22:52 UTC; unix
